@@ -26,11 +26,34 @@ class Invalidate(Behavior):
         if key is not None:
             del self[key]
         else:
-            # need to use keys instead of iter here
             for key in self.keys():
                 del self[key]
 
 
+@implementer(IInvalidate)
+class VolatileStorageInvalidate(Behavior):
+    """Plumbing behavior for invalidating volatile storages like
+    ``DictStorage`` or ``OdictStorage``.
+    """
+
+    @default
+    def invalidate(self, key=None):
+        """Raise KeyError if child does not exist for key if given.
+        """
+        storage = self.storage
+        if key is not None:
+            if key in self.keys():
+                try:
+                    del storage[key]
+                except KeyError, e:
+                    pass # ignore, key is valid, but not on storage right now
+            else:
+                raise KeyError(key)
+        else:
+            for key in storage.keys():
+                del storage[key]
+
+
 @implementer(ICache)
 class Cache(Behavior):
 
